
#include <packagekit-glib/packagekit.h>
#include <gtk/gtk.h>
#include <config.h>

static void
_client_error_cb (PkClient        *client,
                  PkErrorCodeEnum  error_code,
                  const gchar     *details,
                  const gchar     *token)
{
  g_debug ("%s(%s): error '%s' (%s)", __FUNCTION__, token,
                                      pk_error_enum_to_text (error_code),
                                      details);
}

static void
_client_message_cb (PkClient      *client,
                    PkMessageEnum  message,
                    const gchar   *details,
                    const gchar   *token)
{
  g_debug ("%s(%s) '%s' '%s'", __FUNCTION__, token,
                               pk_message_enum_to_text (message),
                               details);
}

static void
_client_progress_cb (PkClient       *client,
                     guint           percentage,
                     guint           subpercentage,
                     guint           elapsed,
                     guint           remaining,
                     const gchar    *token)
{
  g_debug ("%s(%s) %d", __FUNCTION__, token, percentage);
}

static void
_client_status_cb (PkClient     *client,
                   PkStatusEnum  status,
                   const gchar  *token)
{
  g_debug ("%s(%s) %s", __FUNCTION__, token,
                        pk_status_enum_to_text (status));
}

static void
_client_finished_cb (PkClient       *client,
                     PkExitEnum      exit,
                     guint           runtime,
                     const gchar    *token)
{
  g_debug ("%s(%s) %s", __FUNCTION__, token,
                        pk_exit_enum_to_text (exit));

  g_object_unref (client);
}

static void
install_package (gchar const  *package_id,
                 gchar const  *token)
{
  PkClient    *client;
  gchar const *package_ids[2] = { 0, };
  GError      *error = NULL;
  gboolean     ret;

  client = pk_client_new ();
  g_signal_connect (client, "error-code",
                    G_CALLBACK (_client_error_cb), (gpointer) token);
  g_signal_connect (client, "message",
                    G_CALLBACK (_client_message_cb), (gpointer) token);
  g_signal_connect (client, "progress-changed",
                    G_CALLBACK (_client_progress_cb), (gpointer) token);
  g_signal_connect (client, "finished",
                    G_CALLBACK (_client_finished_cb), (gpointer) token);
  g_signal_connect (client, "status-changed",
                    G_CALLBACK (_client_status_cb), (gpointer) token);

  g_debug ("%s() (%s) %s", __FUNCTION__, token, package_id);

  package_ids[0] = package_id;
#ifdef HAVE_PACKAGEKIT_GLIB_0_5
  ret = pk_client_install_packages (client, TRUE, (gchar **) package_ids, &error);
#else
  ret = pk_client_install_packages (client, (gchar **) package_ids, &error);
#endif

  if (error)
  {
    g_warning ("%s : %s", G_STRLOC, error->message);
    g_clear_error (&error);
  }
}

int
main (int     argc,
      char  **argv)
{

  gtk_init (&argc, &argv);

  if (argc < 3)
  {
    g_debug ("Pass 2 package-ids, e.g. 'postr;0.12.3-1ubuntu2;all; gnometris;1:2.28.0-0ubuntu1;i386;'");
  } else {
    install_package (argv[1], "p1");
    install_package (argv[2], "p2");
  }

  gtk_main ();


  return 0;
}

