#!/usr/bin/perl

if (eval {require LWP::Simple;}) {
} else {
    print "You need to install Perl LWP module\n";
    print "  Moblin/Fedora: sudo yum install perl-5\n";  
    print "  Ubuntu: sudo apt-get install perl-base\n";
    exit;
}
use LWP::Simple;
use File::Copy;
use Cwd;
use Term::ANSIColor;
use File::Path;
use strict;
no strict `vars`;

sub getUserInput {
   my($prompt, $default) = @_;
   print "$prompt";
   chomp ($input = <>);
   $input =~s/\s+//g;
   if ($input ne "")	{
       $default = $input;
   }
   return $default;
}

print "\nSync Garage AppList Utility\n";
$| = 1;
print "Downloading garage_apps.xml...";

$url = "http://garage.moblin.org/garage/xml";
$garage_url = "garage_apps.xml";	 
$status = LWP::Simple::getstore($url,$garage_url);
if (is_success($status)) {
    print "Done\n";
}
else {
    print "\nError downloading file ($status)\n";
    exit 1;
}

# Opening applist.xml file
print "Processing garage_apps.xml...";
if (-e $garage_url) {
    chmod 0777,$garage_url;
    open FILE, $garage_url or die $!;
    @lines=<FILE>;
    $arrlen = @lines;
    close (FILE);

    print "Done\n";
    # Deleting the file garage_apps.xml
    unless (unlink($garage_url)) {
	print "\nFile $garage_url was not deleted, Please delete it manually\n";
    }
}
else {
    print "\nThe file './garage_apps.xml' could not be found.\n";
    print "This file can be generated from the moblin server by going to: ";
    print "http://garage.moblin.org/garage/xml in your browser.\n";
    exit 1;
}

# Get applist.xml location
$applistPath = getcwd()."/applist.xml";
$applistPath = &getUserInput ("\nPlease enter destination for applist.xml ".
			      "[$applistPath]: ", $applistPath);

# Get icon dir
$iconDir = Cwd::getcwd."/appicons/";
$iconDir = &getUserInput ("Please enter the directory for the garage icons ".
			  "[$iconDir]: ", $iconDir);

# Make directory to copy all icons with permission 777 
if (-d $iconDir) {
    print color("red"),
          "\n Warning: The icon directory exists.\n".
	  " New icons will be copied into this directory.\n",
	  color ("reset");
    $option = &getUserInput ("Do you want to continue (y/n)[n]? ", "n");
    if (($option ne 'Y') && ($option ne 'yes') && ($option ne 'y')) {
	exit 1;
    }
    #Removes the appicons directory so that can be created again 
    #to dangerous: system('rm',-'r',$iconDir);
}

File::Path::mkpath($iconDir);

# Download icons.  Path to icon is in http_link=<url>
$totIcons = 0;
for ($i=0; $i<$arrlen; $i++) {
    if(@lines[$i]=~/icon=\"http/) {	
	$toticons++;
    }
}
$index = 0;
for ($i=0; $i<$arrlen; $i++) {
    if(@lines[$i]=~/icon=\"http/) {	
	$index++;
	$temp = $lines[$i];
	$temp =~ /^(.*)(\")(.*)(\")$/;
	$imageLink = $3;
	$temp =~ /^(.*)(\")(.*)(\/icons\/)(.*)(\")$/;
	$name = $5;
	$locImage ="$iconDir/" . $name;

	print "($index/$toticons) Downloading: $name...";
	$| = 1;
	my $status = LWP::Simple::getstore($imageLink,$locImage);

	if (is_success($status)) {
	    print "Done\n";
	}
	else {
	    print "\nError downloading $5 ($status)\nContinuing anyway...";
	}

	#Now replacing icon name in newApplist.xml
	$temp =~ s/$imageLink/$name/g;
	$lines[$i]=$temp;
    }
}
open FILE2,"> $applistPath" or die $!;
print FILE2 "@lines";
close(FILE2);

print color("blue"),
    "\nSuccessfully completed update.\n".
    " $applistPath\n".
    " $iconDir\n",
    color ("reset");

